@@ -1,8 +1,20 @@
+import sys
 # File modified under the Apache Licence 2.0 spec. Modified by Aero Technologies.
 
 try:
     import metaflow_custom.plugins as ext_plugins
-except ImportError:
+except ImportError as e:
+    ver = sys.version_info[0] * 10 + sys.version_info[1]
+    if ver >= 36:
+        # e.path is not None if the error stems from some other place than here
+        # so don't error ONLY IF the error is importing this module (but do
+        # error if there is a transitive import error)
+        if not (isinstance(e, ModuleNotFoundError) and e.path is None):
+            print(
+                "Cannot load metaflow_custom plugins -- "
+                "if you want to ignore, uninstall metaflow_custom package")
+            raise
+
     class _fake(object):
         def __init__(self, **kwargs):
             self.__dict__.update(kwargs)
@@ -28,7 +40,7 @@ def get_plugin_cli():
 
     # Add new CLI commands in this list
     from . import package_cli
-    from .aws.aero import batch_cli
+    from .aws.batch import batch_cli
     from .aws.step_functions import step_functions_cli
 
     return ext_plugins.get_plugin_cli() + [
@@ -52,7 +64,7 @@ from .catch_decorator import CatchDecorator
 from .timeout_decorator import TimeoutDecorator
 from .environment_decorator import EnvironmentDecorator
 from .retry_decorator import RetryDecorator
-from .aws.aero.batch_decorator import BatchDecorator, ResourcesDecorator
+from .aws.batch.batch_decorator import BatchDecorator, ResourcesDecorator
 from .aws.step_functions.step_functions_decorator import StepFunctionsInternalDecorator
 from .conda.conda_step_decorator import CondaStepDecorator
 
@@ -83,8 +95,14 @@ from .conda.conda_flow_decorator import CondaFlowDecorator
 from .aws.step_functions.schedule_decorator import ScheduleDecorator
 FLOW_DECORATORS = _merge_lists([CondaFlowDecorator, ScheduleDecorator], ext_plugins.FLOW_DECORATORS, 'name')
 
+
 # Sidecars
-SIDECARS = ext_plugins.SIDECARS
+from ..mflog.save_logs_periodically import SaveLogsPeriodicallySidecar
+from metaflow.metadata.heartbeat import MetadataHeartBeat
+
+SIDECARS = {'save_logs_periodically': SaveLogsPeriodicallySidecar,
+            'heartbeat': MetadataHeartBeat}
+SIDECARS.update(ext_plugins.SIDECARS)
 
 # Add logger
 from .debug_logger import DebugEventLogger
@@ -100,3 +118,4 @@ MONITOR_SIDECARS.update(ext_plugins.MONITOR_SIDECARS)
 
 SIDECARS.update(LOGGING_SIDECARS)
 SIDECARS.update(MONITOR_SIDECARS)
+
