@@ -13,18 +13,19 @@ def get_aws_client(module, with_error=False, params={}):
     user_home = str(Path.home())
     config = configparser.ConfigParser()
 
-    # Handle case of AWS Batch - no credentials file
-    try:
-        with open(f"{user_home}/.aws/credentials") as f:
-            config.read_file(f)
+    # # Handle case of AWS Batch - no credentials file
+    # try:
+    #     with open(f"{user_home}/.aws/credentials") as f:
+    #         config.read_file(f)
 
-        if 'aero' not in config:
-            raise Exception("Credentials aren't set. Make sure you run 'aero account login' first.")
+    #     if 'aero' not in config:
+    #         raise Exception("Credentials aren't set. Make sure you run 'aero account login' first.")
 
-        os.environ['AWS_PROFILE'] = 'aero'
+    #     os.environ['AWS_PROFILE'] = 'aero'
 
-    except IOError:
-        pass
+    # except IOError:
+    #     print("Error ocurred reading creds")
+    #     pass
 
 
     try:
