@@ -13,12 +13,12 @@ from metaflow.plugins import ResourcesDecorator, BatchDecorator, RetryDecorator
 from metaflow.parameters import deploy_time_eval
 from metaflow.util import compress_list, dict_to_cli_options, to_pascalcase
 from metaflow.metaflow_config import SFN_IAM_ROLE, \
-    EVENTS_SFN_ACCESS_IAM_ROLE, SFN_DYNAMO_DB_TABLE
+    EVENTS_SFN_ACCESS_IAM_ROLE, SFN_DYNAMO_DB_TABLE, SFN_EXECUTION_LOG_GROUP_ARN
 from metaflow import R
 
 from .step_functions_client import StepFunctionsClient
 from .event_bridge_client import EventBridgeClient
-from ..aero.batch import Batch
+from ..batch.batch import Batch
 
 
 class StepFunctionsException(MetaflowException):
@@ -83,7 +83,7 @@ class StepFunctions(object):
             return 'No triggers defined. '\
                 'You need to launch this workflow manually.'
 
-    def deploy(self):
+    def deploy(self, log_execution_history):
         if SFN_IAM_ROLE is None:
             raise StepFunctionsException("No IAM role found for Aero "
                                          "scheduler. You can create one "
@@ -94,11 +94,21 @@ class StepFunctions(object):
                                          "re-configure Metaflow using "
                                          "*metaflow configure aws* on your "
                                          "terminal.")
+        if log_execution_history:
+            if SFN_EXECUTION_LOG_GROUP_ARN is None:
+                raise StepFunctionsException("No AWS CloudWatch Logs log "
+                                             "group ARN found for emitting "
+                                             "state machine execution logs for "
+                                             "your workflow. You can set it in "
+                                             "your environment by using the "
+                                             "METAFLOW_SFN_EXECUTION_LOG_GROUP_ARN "
+                                             "environment variable.")
         try:
             self._state_machine_arn = self._client.push(
                     name = self.name, 
                     definition = self.to_json(), 
-                    roleArn = SFN_IAM_ROLE
+                    role_arn = SFN_IAM_ROLE,
+                    log_execution_history = log_execution_history
                 )
         except Exception as e:
             raise StepFunctionsException(repr(e))
@@ -288,7 +298,16 @@ class StepFunctions(object):
     def _process_parameters(self):
         parameters = []
         has_schedule = self._cron() is not None
+        seen = set()
         for var, param in self.flow._get_parameters():
+            # Throw an exception if the parameter is specified twice.
+            norm = param.name.lower()
+            if norm in seen:
+                raise MetaflowException("Parameter *%s* is specified twice. "
+                                        "Note that parameter names are "
+                                        "case-insensitive." % param.name)
+            seen.add(norm)
+
             valuetype = param.kwargs.get('type', str)
             value = deploy_time_eval(param.kwargs.get('default'))
             required = param.kwargs.get('required', False)
@@ -299,6 +318,7 @@ class StepFunctions(object):
                                         "ambiguous. It does not have a "
                                         "default and it is not required."
                                         % param.name)
+
             # Throw an exception if a schedule is set for a flow with required
             # parameters with no defaults. We currently don't have any notion
             # of data triggers in AWS Event Bridge.
@@ -559,12 +579,24 @@ class StepFunctions(object):
 
         # Resolve AWS Batch resource requirements.
         batch_deco = [deco for deco in node.decorators
-                        if deco.name == 'aero'][0]
+                        if deco.name == 'batch'][0]
         resources = batch_deco.attributes
 
         # Resolve retry strategy.
         user_code_retries, total_retries= self._get_retries(node)
 
+        task_spec = {
+            'flow_name': attrs['metaflow.flow_name'],
+            'step_name': attrs['metaflow.step_name'],
+            'run_id': 'sfn-$METAFLOW_RUN_ID',
+            # Use AWS Batch job identifier as the globally unique 
+            # task identifier.
+            'task_id': '$AWS_BATCH_JOB_ID',
+            # Since retries are handled by AWS Batch, we can rely on
+            # AWS_BATCH_JOB_ATTEMPT as the job counter.
+            'retry_count': '$((AWS_BATCH_JOB_ATTEMPT-1))'
+        }
+
         return Batch(self.metadata, self.environment) \
                 .create_job(
                         step_name=node.name,
@@ -572,6 +604,7 @@ class StepFunctions(object):
                                                 input_paths,
                                                 self.code_package_url,
                                                 user_code_retries),
+                        task_spec=task_spec,
                         code_package_sha=self.code_package.sha,
                         code_package_url=self.code_package_url,
                         code_package_ds=self.datastore.TYPE,
@@ -695,7 +728,7 @@ class StepFunctions(object):
             '--input-paths %s' % paths,
             # Set decorator to aero to execute `task_*` hooks for aero
             # decorator.
-            '--with=aero'
+            '--with=batch'
         ]
         if any(self.graph[n].type == 'foreach' for n in node.in_funcs):
             # We set the `METAFLOW_SPLIT_INDEX` through JSONPath-foo
@@ -703,8 +736,8 @@ class StepFunctions(object):
             step.append('--split-index $METAFLOW_SPLIT_INDEX')
         if self.tags:
             step.extend('--tag %s' % tag for tag in self.tags)
-        if self.namespace:
-            step.append('--namespace %s' % self.namespace)
+        if self.namespace is not None:
+            step.append('--namespace=%s' % self.namespace)
         cmds.append(' '.join(entrypoint + top_level + step))
         return ' && '.join(cmds)
 
